@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 2015-2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 2015-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -41,11 +41,21 @@ static NvU64 osCountTailPages(NvU64 sysPagePhysAddr)
     return 0;
 }
 
-static void osAllocReleasePage(NvU64 sysPagePhysAddr)
+static void osAllocReleasePage(NvU64 sysPagePhysAddr, NvU32 pageCount)
 {
     return;
 }
 
+static NV_STATUS osOfflinePageAtAddress(NvU64 address)
+{
+    return NV_ERR_GENERIC;
+}
+
+static NvU8 osGetPageShift(void)
+{
+    return 0;
+}
+
 NV_STATUS scrubCheck(OBJMEMSCRUB *pScrubber, PSCRUB_NODE *ppList, NvU64 *size)
 {
     return NV_ERR_GENERIC;
@@ -218,6 +228,27 @@ pmaStateCheck(PMA *pPma)
     return NV_TRUE;
 }
 
+NV_STATUS
+pmaCheckRangeAgainstRegionDesc
+(
+    PMA   *pPma,
+    NvU64  base,
+    NvU64  size
+)
+{
+    PMA_REGION_DESCRIPTOR *pRegionDesc;
+    NvU32 regId = findRegionID(pPma, base);
+    pRegionDesc = pPma->pRegDescriptors[regId];
+
+    if ((base < pRegionDesc->base) ||
+        ((base + size - 1) > pRegionDesc->limit))
+    {
+        return NV_ERR_INVALID_STATE;
+    }
+
+    return NV_OK;
+}
+
 void
 pmaSetBlockStateAttribUnderPmaLock
 (
@@ -242,9 +273,12 @@ pmaSetBlockStateAttribUnderPmaLock
     numFrames = size >> PMA_PAGE_SHIFT;
     baseFrame = (base - pPma->pRegDescriptors[regId]->base) >> PMA_PAGE_SHIFT;
 
+    // Ensure accessing the frame data would not go out of bound in lower level
+    NV_ASSERT_OR_RETURN_VOID((base + size - 1) <= pPma->pRegDescriptors[regId]->limit);
+
     for (i = 0; i < numFrames; i++)
     {
-        pPma->pMapInfo->pmaMapChangeStateAttribEx(pMap, (baseFrame + i), pmaState, pmaStateWriteMask);
+        pPma->pMapInfo->pmaMapChangeStateAttrib(pMap, (baseFrame + i), pmaState, pmaStateWriteMask);
     }
 }
 
@@ -373,6 +407,10 @@ _pmaCleanupNumaReusePages
         // Since we set the NUMA_REUSE bit when we decide to reuse the pages,
         // we know exactly which pages to free both to OS and in PMA bitmap.
         //
+        NvU8 osPageShift = osGetPageShift();
+
+        NV_ASSERT_OR_RETURN(PMA_PAGE_SHIFT >= osPageShift, NV_ERR_INVALID_STATE);
+
         for (i = 0; i < numFrames; i++)
         {
             currentStatus = pPma->pMapInfo->pmaMapRead(pPma->pRegions[regId], (frameNum + i), NV_TRUE);
@@ -380,9 +418,9 @@ _pmaCleanupNumaReusePages
 
             if (currentStatus & ATTRIB_NUMA_REUSE)
             {
-                osAllocReleasePage(sysPagePhysAddr);
-                pPma->pMapInfo->pmaMapChangeStateAttribEx(pPma->pRegions[regId], (frameNum + i),
-                                                          STATE_FREE, (STATE_MASK | ATTRIB_NUMA_REUSE));
+                osAllocReleasePage(sysPagePhysAddr, 1 << (PMA_PAGE_SHIFT - osPageShift));
+                pPma->pMapInfo->pmaMapChangeStateAttrib(pPma->pRegions[regId], (frameNum + i),
+                                                        STATE_FREE, (STATE_MASK | ATTRIB_NUMA_REUSE));
             }
         }
 
@@ -519,7 +557,7 @@ _pmaEvictPages
     NvU64             evictPageCount,
     NvU64            *allocPages,
     NvU64             allocPageCount,
-    NvU32             pageSize,
+    NvU64             pageSize,
     NvU64             physBegin,
     NvU64             physEnd,
     MEMORY_PROTECTION prot
@@ -824,7 +862,7 @@ _pmaPredictOutOfMemory
 (
     PMA                    *pPma,
     NvLength                allocationCount,
-    NvU32                   pageSize,
+    NvU64                   pageSize,
     PMA_ALLOCATION_OPTIONS *allocationOptions
 )
 {
@@ -839,7 +877,15 @@ _pmaPredictOutOfMemory
 
     if ((alignFlag && (alignment == _PMA_2MB)) || pageSize == _PMA_2MB)
     {
-        free2mbPages = pPma->pmaStats.numFree2mbPages;
+        if (allocationOptions->flags & PMA_ALLOCATE_PROTECTED_REGION)
+        {
+            free2mbPages = pPma->pmaStats.numFree2mbPagesProtected;
+        }
+        else
+        {
+            free2mbPages = pPma->pmaStats.numFree2mbPages -
+                           pPma->pmaStats.numFree2mbPagesProtected;
+        }
 
         // If we have at least one page free, don't fail a partial allocation
         if (partialFlag && (free2mbPages > 0))
@@ -854,7 +900,15 @@ _pmaPredictOutOfMemory
     }
 
     // Do a quick check and exit early if we are in OOM case
-    bytesFree = pPma->pmaStats.numFreeFrames << PMA_PAGE_SHIFT;
+    if (allocationOptions->flags & PMA_ALLOCATE_PROTECTED_REGION)
+    {
+        bytesFree = pPma->pmaStats.numFreeFramesProtected << PMA_PAGE_SHIFT;
+    }
+    else
+    {
+        bytesFree = (pPma->pmaStats.numFreeFrames -
+                     pPma->pmaStats.numFreeFramesProtected) << PMA_PAGE_SHIFT;
+    }
 
     // If we have at least one page free, don't fail a partial allocation
     if (partialFlag && (bytesFree >= pageSize))
@@ -1185,7 +1239,8 @@ pmaRegisterBlacklistInfo
     PMA                    *pPma,
     NvU64                   physAddrBase,
     PMA_BLACKLIST_ADDRESS  *pBlacklistPageBase,
-    NvU32                   blacklistCount
+    NvU32                   blacklistCount,
+    NvBool                  bBlacklistFromInforom
 )
 {
     NvU32 i;
@@ -1225,6 +1280,45 @@ pmaRegisterBlacklistInfo
         pmaSetBlockStateAttrib(pPma, alignedBlacklistAddr, PMA_GRANULARITY, ATTRIB_BLACKLIST, ATTRIB_BLACKLIST);
         pBlacklistChunk->bIsValid = NV_TRUE;
 
+        //
+        // In NUMA systems, memory allocation comes directly from kernel, which
+        // won't check for ATTRIB_BLACKLIST. So pages need to be blacklisted
+        // directly through the kernel.
+        //
+        // This is only needed for NUMA systems that auto online NUMA memory.
+        // Other systems (e.g., P9) already do blacklisting in nvidia-persistenced.
+        //
+        if (pPma->bNuma && pPma->bNumaAutoOnline)
+        {
+            //
+            // Only blacklist pages from inforom (i.e., during heap/PMA init) need 
+            // to be blacklisted with kernel here. The blacklist pages stored in 
+            // inforom need to remain blacklisted persistently across GPU resets -
+            // kernel won't automatically blacklist these so RM must do it
+            // explicitly here.
+            //
+            // Blacklist pages not from inforom (i.e., from ECC interrupt handling)
+            // do not need to be blacklisted with kernel. This is because the ECC
+            // interrupt will automatically trigger kernel itself to blacklist the page.
+            //
+            if (bBlacklistFromInforom)
+            {
+                NV_STATUS status;
+
+                // Use physOffset without 64K alignment, because kernel may use a different page size.
+                NV_PRINTF(LEVEL_INFO,
+                          "NUMA enabled - blacklisting page through kernel at address 0x%llx (GPA) 0x%llx (SPA)\n",
+                          pBlacklistPageBase[blacklistEntryIn].physOffset,
+                          pBlacklistPageBase[blacklistEntryIn].physOffset + pPma->coherentCpuFbBase);
+
+                status = osOfflinePageAtAddress(pBlacklistPageBase[blacklistEntryIn].physOffset + pPma->coherentCpuFbBase);
+                if (status != NV_OK)
+                {
+                    NV_PRINTF(LEVEL_ERROR, "osOfflinePageAtAddress() failed with status: %d\n", status);
+                }
+            }
+        }
+
         blacklistEntryIn++;
     }
 
